===============================
trello-csv-schedule
===============================

.. image:: https://badge.fury.io/py/trello-csv-schedule.png
    :target: http://badge.fury.io/py/trello-csv-schedule

.. image:: https://pypip.in/d/trello-csv-schedule/badge.png
        :target: https://pypi.python.org/pypi/trello-csv-schedule

Tools to two-way sync Trello & CSV to easily manage due date.

Features
=========

* Manage Trello access credentials
* Download cards of boards to CSV file
* Sync changes of due date in CSV to Trello board
